@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -20,7 +20,7 @@
  * Compact Disc Digital Audio (CDDA) Input Plugin 
  *   by Mike Melanson (melanson@pcisys.net)
  *
- * $Id: input_cdda.c,v 1.72 2005/05/28 09:26:59 jstembridge Exp $
+ * $Id: input_cdda.c,v 1.80 2005/11/15 13:29:10 miguelfreitas Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,7 +32,12 @@
 #include <unistd.h>
 
 #include <sys/types.h>
+#ifdef SYS_PARAM_H
+#include <sys/param.h>
+#endif
+#ifdef HAVE_DIRENT_H
 #include <dirent.h>
+#endif
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -74,7 +79,7 @@
 #define CDDB_SERVER             "freedb.freedb.org"
 #define CDDB_PORT               8880
 #define CDDB_PROTOCOL           6
-#define CDDB_TIMEOUT            2000
+#define CDDB_TIMEOUT            5000
 
 /* CD-relevant defines and data structures */
 #define CD_SECONDS_PER_MINUTE   60
@@ -684,18 +689,26 @@ static int read_cdrom_frames(cdda_input_plugin_t *this_gen, int frame, int num_f
   unsigned char *data) {
 
   int fd = this_gen->fd;
+#if  __FreeBSD_version < 501106
   struct ioc_read_audio cdda;
+#endif
 
   while( num_frames ) {
+#if  __FreeBSD_version < 501106
     cdda.address_format = CD_MSF_FORMAT;
     cdda.address.msf.minute = frame / CD_SECONDS_PER_MINUTE / CD_FRAMES_PER_SECOND;
     cdda.address.msf.second = (frame / CD_FRAMES_PER_SECOND) % CD_SECONDS_PER_MINUTE;
     cdda.address.msf.frame = frame % CD_FRAMES_PER_SECOND;
     cdda.nframes = 1;
     cdda.buffer = data;
+#endif
 
+#if  __FreeBSD_version >= 501106
+    if (pread(fd, data, CD_RAW_FRAME_SIZE, frame * CD_RAW_FRAME_SIZE) != CD_RAW_FRAME_SIZE) {
+#else
     /* read a frame */
     if(ioctl(fd, CDIOCREADAUDIO, &cdda) < 0) {
+#endif
       perror("CDIOCREADAUDIO");
       return -1;
     }
@@ -1383,6 +1396,7 @@ static int _cdda_load_cached_cddb_infos(cdda_input_plugin_t *this) {
 	  char buffer[256], *ln, *pt;
 	  char buf[256];
 	  int  tnum;
+	  char *dtitle = NULL;
 	  
 	  while((ln = fgets(buffer, 255, fd)) != NULL) {
 
@@ -1395,10 +1409,19 @@ static int _cdda_load_cached_cddb_infos(cdda_input_plugin_t *this) {
 	      if(pt)
 		pt++;
 
+	      if (dtitle != NULL)
+	      {
+		dtitle = (char *) realloc(dtitle, strlen(dtitle) + strlen(pt) + 1);
+		strcat(dtitle,pt);
+		pt = dtitle;
+	      }
+	      dtitle = strdup(pt);
+ 
 	      artist = pt;
-	      title = strchr(pt, '/');
+	      title = strstr(pt, " / ");
 	      if(title) {
-		*title++ = 0;
+		*title++ = '\0';
+		title += 2;
 	      }
 	      else {
 		title = artist;
@@ -1410,11 +1433,24 @@ static int _cdda_load_cached_cddb_infos(cdda_input_plugin_t *this) {
 
 	      this->cddb.disc_title = strdup(title);
 	    }
+	    else if(sscanf(buffer, "DYEAR=%s", &buf[0]) == 1) {
+	      pt = strrchr(buffer, '=');
+	      pt++;
+	      if (pt != NULL && strlen(pt) == 4)
+		this->cddb.disc_year = strdup(pt);
+	    }
 	    else if(sscanf(buffer, "TTITLE%d=%s", &tnum, &buf[0]) == 2) {
 	      pt = strrchr(buffer, '=');
 	      if(pt)
 		pt++;
-	      this->cddb.track[tnum].title = strdup(pt);
+	      if (this->cddb.track[tnum].title == NULL)
+		this->cddb.track[tnum].title = strdup(pt); 
+	      else
+	      {
+		this->cddb.track[tnum].title
+		  = (char *) realloc(this->cddb.track[tnum].title,strlen(this->cddb.track[tnum].title) + strlen(pt) + 1);
+		strcat(this->cddb.track[tnum].title,pt);
+	      }
 	    }
 	    else {
 	      if(!strncmp(buffer, "EXTD=", 5)) {
@@ -1427,13 +1463,15 @@ static int _cdda_load_cached_cddb_infos(cdda_input_plugin_t *this) {
 		    char year[5];
 
 		    snprintf(year, 5, "%d", nyear);
-		    this->cddb.disc_year = strdup(year);
+		    if (this->cddb.disc_year == NULL)
+		      this->cddb.disc_year = strdup(year);
 		  }
 		}
 	      }
 	    }
 	  }
 	  fclose(fd);
+	  free(dtitle);
 	}
 	
 	closedir(dir);
@@ -1473,7 +1511,7 @@ static void _cdda_save_cached_cddb_infos(cdda_input_plugin_t *this, char *fileco
     return;
   }
   else {
-    fprintf(fd, filecontent);
+    fprintf(fd, "%s", filecontent);
     fclose(fd);
   }
   
@@ -1696,6 +1734,7 @@ static int _cdda_cddb_retrieve(cdda_input_plugin_t *this) {
       char buf[2048];
       int tnum;
       int bufsize = strlen(buffercache);
+      char *dtitle = NULL;
 
       memset(&buffer, 0, sizeof(buffer));
       _cdda_cddb_socket_read(this, buffer, sizeof(buffer) - 1);
@@ -1706,10 +1745,21 @@ static int _cdda_cddb_retrieve(cdda_input_plugin_t *this) {
 
         pt = strrchr(buffer, '=');
         if (pt) {
-          artist = pt+1;
-          title = strchr(pt+1, '/');
+          pt++;
+
+          if (dtitle != NULL)
+          {
+            dtitle = (char *) realloc(dtitle, strlen(dtitle) + strlen(pt) + 1);
+            strcat(dtitle,pt);
+            pt = dtitle;
+          }
+          dtitle = strdup(pt);
+
+          artist = pt;
+          title = strstr(pt, " / ");
           if (title) {
-            *title++ = 0;
+            *title++ = '\0';
+            title += 2;
           }
           else {
             title = artist;
@@ -1722,12 +1772,28 @@ static int _cdda_cddb_retrieve(cdda_input_plugin_t *this) {
           this->cddb.disc_title = strdup(title);
         }
       }
+      else if(sscanf(buffer, "DYEAR=%s", &buf[0]) == 1) {
+        char *pt;
+
+        pt = strrchr(buffer, '=');
+        pt++;
+        if (pt != NULL && strlen(pt) == 4)
+          this->cddb.disc_year = strdup(pt);
+      }
       else if (sscanf(buffer, "TTITLE%d=%s", &tnum, &buf[0]) == 2) {
         char *pt;
 
         pt = strrchr(buffer, '=');
         if (pt) {
-          this->cddb.track[tnum].title = strdup(pt+1);
+	  pt++;
+          if (this->cddb.track[tnum].title == NULL)
+            this->cddb.track[tnum].title = strdup(pt);
+          else
+          {
+            this->cddb.track[tnum].title
+              = (char *) realloc(this->cddb.track[tnum].title,strlen(this->cddb.track[tnum].title) + strlen(pt) + 1);
+            strcat(this->cddb.track[tnum].title,pt);
+          }
         }
       }
       else {
@@ -1741,11 +1807,13 @@ static int _cdda_cddb_retrieve(cdda_input_plugin_t *this) {
               char year[5];
 
               snprintf(year, 5, "%d", nyear);
-              this->cddb.disc_year = strdup(year);
+              if (this->cddb.disc_year == NULL)
+                this->cddb.disc_year = strdup(year);
             }
           }
         }
       }
+      free(dtitle);
     }
 
     /* Save cddb info and close socket */
@@ -2548,6 +2616,16 @@ static char *cdda_class_get_description (input_class_t *this_gen) {
 
 static void cdda_class_dispose (input_class_t *this_gen) {
   cdda_input_class_t  *this = (cdda_input_class_t *) this_gen;
+  config_values_t     *config = this->xine->config;
+
+  config->unregister_callback(config, "media.audio_cd.device");
+  config->unregister_callback(config, "media.audio_cd.use_cddb");
+  config->unregister_callback(config, "media.audio_cd.cddb_server");
+  config->unregister_callback(config, "media.audio_cd.cddb_port");
+  config->unregister_callback(config, "media.audio_cd.cddb_cachedir");
+#ifdef CDROM_SELECT_SPEED
+  config->unregister_callback(config, "media.audio_cd.drive_slowdown");
+#endif
 
   free (this->mrls);
   free (this);
@@ -2641,7 +2719,7 @@ static void *init_plugin (xine_t *xine, void *data) {
 
 plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_INPUT | PLUGIN_MUST_PRELOAD, 16, "CD", XINE_VERSION_CODE, NULL, init_plugin },
+  { PLUGIN_INPUT | PLUGIN_MUST_PRELOAD, 17, "CD", XINE_VERSION_CODE, NULL, init_plugin },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
