@@ -689,7 +689,7 @@ static input_plugin_t *rtp_class_get_instance (input_class_t *cls_gen,
     }
   }
   
-  this = (rtp_input_plugin_t *) malloc(sizeof(rtp_input_plugin_t));
+  this = (rtp_input_plugin_t *) xine_xmalloc(sizeof(rtp_input_plugin_t));
   this->stream       = stream;
   this->mrl          = mrl;
   this->filename     = filename;
@@ -698,6 +698,7 @@ static input_plugin_t *rtp_class_get_instance (input_class_t *cls_gen,
   this->fh           = -1;
   this->rtp_running  = 0;
   this->preview_size = 0;
+  this->interface = NULL;
 
   if (iptr) this->interface = iptr;
 
@@ -778,7 +779,7 @@ static void *init_class (xine_t *xine, void *data) {
 
 plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */  
-  { PLUGIN_INPUT, 16, "rtp", XINE_VERSION_CODE, NULL, init_class },
+  { PLUGIN_INPUT, 17, "rtp", XINE_VERSION_CODE, NULL, init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
