@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_decoder.c,v 1.56 2005/07/25 20:27:15 tmattern Exp $
+ * $Id: video_decoder.c,v 1.59 2005/11/04 22:37:14 tmattern Exp $
  *
  * xine video decoder plugin using ffmpeg
  *
@@ -250,6 +250,7 @@ static const ff_codec_t ff_video_lookup[] = {
   {BUF_VIDEO_8BPS,        CODEC_ID_8BPS,      "Planar RGB (ffmpeg)"},
   {BUF_VIDEO_SMC,         CODEC_ID_SMC,       "Apple Quicktime Graphics/SMC (ffmpeg)"},
   {BUF_VIDEO_DUCKTM1,     CODEC_ID_TRUEMOTION1,"Duck TrueMotion v1 (ffmpeg)"},
+  {BUF_VIDEO_DUCKTM2,     CODEC_ID_TRUEMOTION2,"Duck TrueMotion v2 (ffmpeg)"},
   {BUF_VIDEO_VMD,         CODEC_ID_VMDVIDEO,   "Sierra VMD Video (ffmpeg)"},
   {BUF_VIDEO_ZLIB,        CODEC_ID_ZLIB,       "ZLIB Video (ffmpeg)"},
   {BUF_VIDEO_MSZH,        CODEC_ID_MSZH,       "MSZH Video (ffmpeg)"},
@@ -281,7 +282,9 @@ static void init_video_codec (ff_video_decoder_t *this, int codec_type) {
 
   for(i = 0; i < sizeof(ff_video_lookup)/sizeof(ff_codec_t); i++)
     if(ff_video_lookup[i].type == codec_type) {
+      pthread_mutex_lock(&ffmpeg_lock);
       this->codec = avcodec_find_decoder(ff_video_lookup[i].id);
+      pthread_mutex_unlock(&ffmpeg_lock);
       _x_meta_info_set_utf8(this->stream, XINE_META_INFO_VIDEOCODEC,
                             ff_video_lookup[i].name);
       break;
@@ -312,8 +315,11 @@ static void init_video_codec (ff_video_decoder_t *this, int codec_type) {
    * this flag here in case we are going to use direct rendering */
   if(this->codec->capabilities & CODEC_CAP_DR1) {
     this->context->flags |= CODEC_FLAG_EMU_EDGE;
-  } 
+  }
+ 
+  pthread_mutex_lock(&ffmpeg_lock);
   if (avcodec_open (this->context, this->codec) < 0) {
+    pthread_mutex_unlock(&ffmpeg_lock);
     xprintf (this->stream->xine, XINE_VERBOSITY_LOG, 
              _("ffmpeg_video_dec: couldn't open decoder\n"));
     free(this->context);
@@ -321,6 +327,7 @@ static void init_video_codec (ff_video_decoder_t *this, int codec_type) {
     _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_HANDLED, 0);
     return;
   }
+  pthread_mutex_unlock(&ffmpeg_lock);
 
   lprintf("lavc decoder opened\n");
 
@@ -1086,6 +1093,7 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
     vo_frame_t *img;
     int         free_img;
     int         got_picture, len;
+    int         got_one_picture = 0;
     int         offset = 0;
     int         codec_type = buf->type & 0xFFFF0000;
 
@@ -1102,11 +1110,11 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
         /* skip decoding b frames if too late */
         this->context->hurry_up = (this->skipframes > 0);
 
-	lprintf("buffer size: %d\n", this->size);
+        lprintf("buffer size: %d\n", this->size);
         len = avcodec_decode_video (this->context, this->av_frame,
                                     &got_picture, &chunk_buf[offset],
                                     this->size);
-	lprintf("consumed size: %d\n", len);
+        lprintf("consumed size: %d, got_picture: %d\n", len, got_picture);
         if ((len <= 0) || (len > this->size)) {
           xprintf (this->stream->xine, XINE_VERBOSITY_DEBUG, 
                     "ffmpeg_video_dec: error decompressing frame\n");
@@ -1138,6 +1146,7 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
 
       if (got_picture && this->av_frame->data[0]) {
         /* got a picture, draw it */
+        got_one_picture = 1;
         if(!this->av_frame->opaque) {
 	  /* indirect rendering */
 
@@ -1226,22 +1235,23 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
 
         if(free_img)
           img->free(img);
-
-      } else {
-        /* no frame, output a bad frame */
-        img = this->stream->video_out->get_frame (this->stream->video_out,
-                                                  this->bih.biWidth,
-                                                  this->bih.biHeight,
-                                                  this->aspect_ratio, 
-                                                  this->output_format,
-                                                  VO_BOTH_FIELDS|this->frame_flags);
-        img->pts       = 0;
-        img->duration  = this->video_step;
-        img->bad_frame = 1;
-        this->skipframes = img->draw(img, this->stream);
-        img->free(img);
       }
     }
+
+    if (!got_one_picture) {
+      /* skipped frame, output a bad frame */
+      img = this->stream->video_out->get_frame (this->stream->video_out,
+                                                this->bih.biWidth,
+                                                this->bih.biHeight,
+                                                this->aspect_ratio, 
+                                                this->output_format,
+                                                VO_BOTH_FIELDS|this->frame_flags);
+      img->pts       = 0;
+      img->duration  = this->video_step;
+      img->bad_frame = 1;
+      this->skipframes = img->draw(img, this->stream);
+      img->free(img);
+    }
   }
 }
 
@@ -1328,7 +1338,9 @@ static void ff_dispose (video_decoder_t *this_gen) {
   lprintf ("ff_dispose\n");
 
   if (this->decoder_ok) {
+    pthread_mutex_lock(&ffmpeg_lock);
     avcodec_close (this->context);
+    pthread_mutex_unlock(&ffmpeg_lock);
 
     this->stream->video_out->close(this->stream->video_out, this->stream);
     this->decoder_ok = 0;
@@ -1485,6 +1497,7 @@ static uint32_t supported_video_types[] = {
   BUF_VIDEO_SMC,
   BUF_VIDEO_VMD,
   BUF_VIDEO_DUCKTM1,
+  BUF_VIDEO_DUCKTM2,
   BUF_VIDEO_ZLIB,
   BUF_VIDEO_MSZH,
   BUF_VIDEO_ASV1,
