@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_out_opengl.c,v 1.51 2005/07/05 11:10:31 mshopf Exp $
+ * $Id: video_out_opengl.c,v 1.54 2005/09/25 00:44:04 miguelfreitas Exp $
  * 
  * video_out_opengl.c, OpenGL based interface for xine
  *
@@ -94,7 +94,6 @@
 #include "video_out.h"
 
 #include "xine_internal.h"
-#include "alphablend.h"
 #include "yuv2rgb.h"
 #include "xineutils.h"
 #include "x11osd.h"
@@ -1424,14 +1423,14 @@ static void opengl_overlay_clut_yuv2rgb(opengl_driver_t  *this, vo_overlay_t *ov
     }
     overlay->rgb_clut++;
   }
-  if (!overlay->clip_rgb_clut) {
-    clut = (clut_t*) overlay->clip_color;
+  if (!overlay->hili_rgb_clut) {
+    clut = (clut_t*) overlay->hili_color;
     for (i = 0; i < sizeof(overlay->color)/sizeof(overlay->color[0]); i++) {
       *((uint32_t *)&clut[i]) =
 	frame->yuv2rgb->yuv2rgb_single_pixel_fun(frame->yuv2rgb, clut[i].y,
 						 clut[i].cb, clut[i].cr);
     }
-    overlay->clip_rgb_clut++;
+    overlay->hili_rgb_clut++;
   }
 }
 
@@ -1446,6 +1445,9 @@ static void opengl_overlay_begin (vo_driver_t *this_gen,
     x11osd_clear(this->xoverlay); 
     XUnlockDisplay (this->display);
   }
+  
+  this->alphablend_extra_data.offset_x = frame_gen->overlay_offset_x;
+  this->alphablend_extra_data.offset_y = frame_gen->overlay_offset_y;
 }
 
 static void opengl_overlay_end (vo_driver_t *this_gen, vo_frame_t *vo_img) {
@@ -1474,16 +1476,16 @@ static void opengl_overlay_blend (vo_driver_t *this_gen,
         XUnlockDisplay (this->display);
       }
     } else {
-      if (!overlay->rgb_clut || !overlay->clip_rgb_clut)
+      if (!overlay->rgb_clut || !overlay->hili_rgb_clut)
         opengl_overlay_clut_yuv2rgb (this, overlay, frame);
 
 #     if BYTES_PER_PIXEL == 3
-      blend_rgb24 ((uint8_t *)frame->rgb, overlay,
+      _x_blend_rgb24 ((uint8_t *)frame->rgb, overlay,
 		   frame->width, frame->height,
 		   frame->width, frame->height,
                    &this->alphablend_extra_data);
 #     elif BYTES_PER_PIXEL == 4
-      blend_rgb32 ((uint8_t *)frame->rgb, overlay,
+      _x_blend_rgb32 ((uint8_t *)frame->rgb, overlay,
 		   frame->width, frame->height,
 		   frame->width, frame->height,
                    &this->alphablend_extra_data);
@@ -1858,15 +1860,8 @@ static vo_driver_t *opengl_open_plugin (video_driver_class_t *class_gen, const v
   this->vo_driver.dispose              = opengl_dispose;
   this->vo_driver.redraw_needed        = opengl_redraw_needed;
 
-  this->yuv2rgb_brightness = config->register_range (config, "video.output.opengl_gamma", 0,
-						     -128, 127,
-						     _("brightness correction"),
-						     _("The brightness correction can be used to "
-						       "lighten or darken the image. It changes the "
-						       "blacklevel without modifying the contrast, "
-						       "but it limits the tonal range."),
-						     0, NULL, NULL);
-  this->yuv2rgb_contrast = 128;
+  this->yuv2rgb_brightness = 0;
+  this->yuv2rgb_contrast   = 128;
   this->yuv2rgb_saturation = 128;
   
   this->yuv2rgb_factory = yuv2rgb_factory_init (YUV_FORMAT, YUV_SWAP_MODE, 
@@ -1999,6 +1994,6 @@ static vo_info_t vo_info_opengl = {
 
 plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */  
-  { PLUGIN_VIDEO_OUT, 20, "opengl", XINE_VERSION_CODE, &vo_info_opengl, opengl_init_class },
+  { PLUGIN_VIDEO_OUT, 21, "opengl", XINE_VERSION_CODE, &vo_info_opengl, opengl_init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
