@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_out_xshm.c,v 1.138 2004/12/12 22:01:29 mroi Exp $
+ * $Id: video_out_xshm.c,v 1.142 2005/09/25 00:44:04 miguelfreitas Exp $
  * 
  * video_out_xshm.c, X11 shared memory extension interface for xine
  *
@@ -61,7 +61,6 @@
 */
 
 #include "xine_internal.h"
-#include "alphablend.h"
 #include "yuv2rgb.h"
 #include "xineutils.h"
 #include "vo_scale.h"
@@ -607,14 +606,14 @@ static void xshm_overlay_clut_yuv2rgb(xshm_driver_t  *this, vo_overlay_t *overla
     }
     overlay->rgb_clut++;
   }
-  if (!overlay->clip_rgb_clut) {
-    clut = (clut_t*) overlay->clip_color;
+  if (!overlay->hili_rgb_clut) {
+    clut = (clut_t*) overlay->hili_color;
     for (i = 0; i < sizeof(overlay->color)/sizeof(overlay->color[0]); i++) {
       *((uint32_t *)&clut[i]) =
 	frame->yuv2rgb->yuv2rgb_single_pixel_fun(frame->yuv2rgb,
 						 clut[i].y, clut[i].cb, clut[i].cr);
     }
-    overlay->clip_rgb_clut++;
+    overlay->hili_rgb_clut++;
   }
 }
 
@@ -629,6 +628,9 @@ static void xshm_overlay_begin (vo_driver_t *this_gen,
     x11osd_clear(this->xoverlay); 
     XUnlockDisplay (this->display);
   }
+  
+  this->alphablend_extra_data.offset_x = frame_gen->overlay_offset_x;
+  this->alphablend_extra_data.offset_y = frame_gen->overlay_offset_y;
 }
 
 static void xshm_overlay_end (vo_driver_t *this_gen, vo_frame_t *vo_img) {
@@ -657,24 +659,24 @@ static void xshm_overlay_blend (vo_driver_t *this_gen,
         XUnlockDisplay (this->display);
       }
     } else {
-      if (!overlay->rgb_clut || !overlay->clip_rgb_clut)
+      if (!overlay->rgb_clut || !overlay->hili_rgb_clut)
         xshm_overlay_clut_yuv2rgb (this, overlay, frame);
  
       switch (this->bpp) {
         case 16:
-         blend_rgb16 ((uint8_t *)frame->image->data, overlay,
+         _x_blend_rgb16 ((uint8_t *)frame->image->data, overlay,
 		      frame->sc.output_width, frame->sc.output_height,
 		      frame->sc.delivered_width, frame->sc.delivered_height,
                       &this->alphablend_extra_data);
          break;
         case 24:
-         blend_rgb24 ((uint8_t *)frame->image->data, overlay,
+         _x_blend_rgb24 ((uint8_t *)frame->image->data, overlay,
 		      frame->sc.output_width, frame->sc.output_height,
 		      frame->sc.delivered_width, frame->sc.delivered_height,
                       &this->alphablend_extra_data);
          break;
         case 32:
-         blend_rgb32 ((uint8_t *)frame->image->data, overlay,
+         _x_blend_rgb32 ((uint8_t *)frame->image->data, overlay,
 		      frame->sc.output_width, frame->sc.output_height,
 		      frame->sc.delivered_width, frame->sc.delivered_height,
                       &this->alphablend_extra_data);
@@ -1236,15 +1238,8 @@ static vo_driver_t *xshm_open_plugin (video_driver_class_t *class_gen, const voi
   
   this->yuv2rgb_mode  = mode;
   this->yuv2rgb_swap  = swapped;
-  this->yuv2rgb_brightness = config->register_range (config, "video.output.xshm_gamma", 0,
-						     -128, 127,
-						     _("brightness correction"),
-						     _("The brightness correction can be used to "
-						       "lighten or darken the image. It changes the "
-						       "blacklevel without modifying the contrast, "
-						       "but it limits the tonal range."),
-						     0, NULL, NULL);
-  this->yuv2rgb_contrast = 128;
+  this->yuv2rgb_brightness = 0;
+  this->yuv2rgb_contrast   = 128;
   this->yuv2rgb_saturation = 128;
   
   this->yuv2rgb_factory = yuv2rgb_factory_init (mode, swapped, 
@@ -1306,6 +1301,6 @@ static vo_info_t vo_info_xshm = {
 
 plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */  
-  { PLUGIN_VIDEO_OUT, 20, "xshm", XINE_VERSION_CODE, &vo_info_xshm, xshm_init_class },
+  { PLUGIN_VIDEO_OUT, 21, "xshm", XINE_VERSION_CODE, &vo_info_xshm, xshm_init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
