@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_out_xv.c,v 1.210 2005/03/06 09:55:35 tmattern Exp $
+ * $Id: video_out_xv.c,v 1.214 2005/09/25 00:44:04 miguelfreitas Exp $
  *
  * video_out_xv.c, X11 video extension interface for xine
  *
@@ -44,12 +44,6 @@
 #include <errno.h>
 #include <math.h>
 
-#if defined (__SVR4) && defined (__sun)
-# include <sys/int_types.h>
-#else
-# include <stdint.h>
-#endif
-
 #include <sys/types.h>
 #if defined(__FreeBSD__)
 #include <machine/param.h>
@@ -75,7 +69,6 @@
 #include "video_out.h"
 #include "xine_internal.h"
 /* #include "overlay.h" */
-#include "alphablend.h"
 #include "deinterlace.h"
 #include "xineutils.h"
 #include "vo_scale.h"
@@ -640,6 +633,9 @@ static void xv_overlay_begin (vo_driver_t *this_gen,
     x11osd_clear(this->xoverlay); 
     XUnlockDisplay (this->display);
   }
+  
+  this->alphablend_extra_data.offset_x = frame_gen->overlay_offset_x;
+  this->alphablend_extra_data.offset_y = frame_gen->overlay_offset_y;
 }
 
 static void xv_overlay_end (vo_driver_t *this_gen, vo_frame_t *vo_img) {
@@ -668,11 +664,11 @@ static void xv_overlay_blend (vo_driver_t *this_gen,
       }
     } else {
       if (frame->format == XINE_IMGFMT_YV12)
-        blend_yuv(frame->vo_frame.base, overlay, 
+        _x_blend_yuv(frame->vo_frame.base, overlay, 
 		  frame->width, frame->height, frame->vo_frame.pitches,
                   &this->alphablend_extra_data);
       else
-        blend_yuy2(frame->vo_frame.base[0], overlay, 
+        _x_blend_yuy2(frame->vo_frame.base[0], overlay, 
 		   frame->width, frame->height, frame->vo_frame.pitches[0],
                    &this->alphablend_extra_data);
     }
@@ -1611,7 +1607,7 @@ static vo_info_t vo_info_xv = {
 
 plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_VIDEO_OUT, 20, "xv", XINE_VERSION_CODE, &vo_info_xv, init_class },
+  { PLUGIN_VIDEO_OUT, 21, "xv", XINE_VERSION_CODE, &vo_info_xv, init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
