@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: audio_decoder.c,v 1.134 2005/04/19 17:42:29 hadess Exp $
+ * $Id: audio_decoder.c,v 1.136 2005/10/30 02:18:35 miguelfreitas Exp $
  *
  *
  * functions that implement audio decoding
@@ -100,7 +100,8 @@ static void *audio_decoder_loop (void *stream_gen) {
       
       running_ticket->release(running_ticket, 0);
       
-      stream->metronom->handle_audio_discontinuity (stream->metronom, DISC_STREAMSTART, 0);
+      if( !stream->gapless_switch )
+        stream->metronom->handle_audio_discontinuity (stream->metronom, DISC_STREAMSTART, 0);
       
       buftype_unknown = 0;
       break;
@@ -119,7 +120,7 @@ static void *audio_decoder_loop (void *stream_gen) {
         }
         first_header = last_header = NULL;
       }
-      
+
       /*
        * wait the output fifos to run dry before sending the notification event
        * to the frontend. this test is only valid if there is only a single
@@ -133,7 +134,7 @@ static void *audio_decoder_loop (void *stream_gen) {
         num_streams = stream->audio_out->get_property(stream->audio_out, AO_PROP_NUM_STREAMS);
         running_ticket->release(running_ticket, 0);
         
-        if( num_bufs > 0 && num_streams == 1 )
+        if( num_bufs > 0 && num_streams == 1 && !stream->early_finish_event)
           xine_usec_sleep (10000);
         else
           break;
@@ -148,7 +149,7 @@ static void *audio_decoder_loop (void *stream_gen) {
 
       pthread_cond_broadcast (&stream->counter_changed);
 
-      if (stream->video_thread) {
+      if (stream->video_thread_created) {
         while (stream->finished_count_video < stream->finished_count_audio) {
           struct timeval tv;
           struct timespec ts;
@@ -490,7 +491,8 @@ void _x_audio_decoder_init (xine_stream_t *stream) {
     pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
     pthread_attr_setschedparam(&pth_attrs, &pth_params);
     pthread_attr_setscope(&pth_attrs, PTHREAD_SCOPE_SYSTEM);
-  
+ 
+    stream->audio_thread_created = 1; 
     if ((err = pthread_create (&stream->audio_thread,
                                &pth_attrs, audio_decoder_loop, stream)) != 0) {
       xprintf (stream->xine, XINE_VERBOSITY_DEBUG, 
@@ -507,14 +509,15 @@ void _x_audio_decoder_shutdown (xine_stream_t *stream) {
   buf_element_t *buf;
   void          *p;
 
-  if (stream->audio_thread) {
+  if (stream->audio_thread_created) {
     /* stream->audio_fifo->clear(stream->audio_fifo); */
 
     buf = stream->audio_fifo->buffer_pool_alloc (stream->audio_fifo);
     buf->type = BUF_CONTROL_QUIT;
     stream->audio_fifo->put (stream->audio_fifo, buf);
     
-    pthread_join (stream->audio_thread, &p); 
+    pthread_join (stream->audio_thread, &p);
+    stream->audio_thread_created = 0;
   }
     
   stream->audio_fifo->dispose (stream->audio_fifo);
