@@ -49,7 +49,6 @@
 #define XINE_ENGINE_INTERNAL
 
 #include "xine_internal.h"
-#include "video_out/alphablend.h"
 #include "xine-engine/bswap.h"
 #include "xineutils.h"
 #include "video_out.h"
@@ -238,10 +237,10 @@ static int _osd_show (osd_object_t *osd, int64_t vpts, int unscaled ) {
     this->event.object.overlay->width = osd->x2 - osd->x1;
     this->event.object.overlay->height = osd->y2 - osd->y1;
  
-    this->event.object.overlay->clip_top    = 0;
-    this->event.object.overlay->clip_bottom = this->event.object.overlay->height;
-    this->event.object.overlay->clip_left   = 0;
-    this->event.object.overlay->clip_right  = this->event.object.overlay->width;
+    this->event.object.overlay->hili_top    = 0;
+    this->event.object.overlay->hili_bottom = this->event.object.overlay->height;
+    this->event.object.overlay->hili_left   = 0;
+    this->event.object.overlay->hili_right  = this->event.object.overlay->width;
    
     /* there will be at least that many rle objects (one for each row) */
     required = osd->y2 - osd->y1;
@@ -298,8 +297,8 @@ static int _osd_show (osd_object_t *osd, int64_t vpts, int unscaled ) {
 #endif
     lprintf("num_rle = %d\n", this->event.object.overlay->num_rle);
   
-    memcpy(this->event.object.overlay->clip_color, osd->color, sizeof(osd->color)); 
-    memcpy(this->event.object.overlay->clip_trans, osd->trans, sizeof(osd->trans)); 
+    memcpy(this->event.object.overlay->hili_color, osd->color, sizeof(osd->color)); 
+    memcpy(this->event.object.overlay->hili_trans, osd->trans, sizeof(osd->trans)); 
     memcpy(this->event.object.overlay->color, osd->color, sizeof(osd->color)); 
     memcpy(this->event.object.overlay->trans, osd->trans, sizeof(osd->trans)); 
   
@@ -1068,7 +1067,7 @@ static int osd_render_text (osd_object_t *osd, int x1, int y1,
       }
       previous = i;
 
-      if (FT_Load_Glyph(osd->ft2->face, i, FT_LOAD_DEFAULT)) {
+      if (FT_Load_Glyph(osd->ft2->face, i, FT_LOAD_DEFAULT | FT_LOAD_NO_HINTING)) {
         xprintf(this->stream->xine, XINE_VERBOSITY_LOG, _("osd: error loading glyph\n"));
         continue;
       }
@@ -1234,7 +1233,7 @@ static int osd_get_text_size(osd_object_t *osd, const char *text, int *width, in
       }
       previous = i;
 
-      if (FT_Load_Glyph(osd->ft2->face, i, FT_LOAD_DEFAULT)) {
+      if (FT_Load_Glyph(osd->ft2->face, i, FT_LOAD_DEFAULT | FT_LOAD_NO_HINTING)) {
         xprintf(this->stream->xine, XINE_VERBOSITY_LOG, _("osd: error loading glyph %i\n"), i);
         text++;
         continue;
@@ -1275,7 +1274,8 @@ static int osd_get_text_size(osd_object_t *osd, const char *text, int *width, in
      * to also add the left bearing because the letter might be shifted left or
      * right and then the right edge is also shifted
      */
-    *width -= osd->ft2->face->glyph->advance.x / 64;
+    if (osd->ft2->face->glyph->bitmap.width)
+        *width -= osd->ft2->face->glyph->advance.x / 64;
     *width += osd->ft2->face->glyph->bitmap.width;
     *width += osd->ft2->face->glyph->bitmap_left;
     *height = osd->ft2->face->size->metrics.height / 64;
