@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine.c,v 1.314 2005/07/21 02:51:14 miguelfreitas Exp $
+ * $Id: xine.c,v 1.319 2005/10/30 02:18:35 miguelfreitas Exp $
  */
 
 /*
@@ -88,7 +88,7 @@ void _x_handle_stream_end (xine_stream_t *stream, int non_user) {
      * if they have called xine_stop explicitly, so only send
      * it if stream playback finished because of stream end reached
      */
-
+    
     xine_event_t event;
 
     event.data_length = 0;
@@ -232,6 +232,7 @@ static xine_ticket_t *ticket_init(void) {
   pthread_mutex_init(&port_ticket->lock, NULL);
   pthread_mutex_init(&port_ticket->revoke_lock, NULL);
   pthread_cond_init(&port_ticket->issued, NULL);
+  pthread_cond_init(&port_ticket->revoked, NULL);
   
   return port_ticket;
 }
@@ -253,15 +254,8 @@ static void set_speed_internal (xine_stream_t *stream, int speed) {
   if( stream->audio_out ) {
     xine->port_ticket->acquire(xine->port_ticket, 1);
     
-    /*
-     * slow motion / fast forward does not play sound, drop buffered
-     * samples from the sound driver
-     */
-    if (speed != XINE_FINE_SPEED_NORMAL && speed != XINE_SPEED_PAUSE)
-      stream->audio_out->control (stream->audio_out, AO_CTRL_FLUSH_BUFFERS, NULL);
-
-    stream->audio_out->control(stream->audio_out,
-			       speed == XINE_SPEED_PAUSE ? AO_CTRL_PLAY_PAUSE : AO_CTRL_PLAY_RESUME, NULL);
+    /* inform audio_out that speed has changed - he knows what to do */
+    stream->audio_out->set_property (stream->audio_out, AO_PROP_CLOCK_SPEED, speed);
     
     xine->port_ticket->release(xine->port_ticket, 1);
   }
@@ -288,7 +282,7 @@ static void stop_internal (xine_stream_t *stream) {
   /*
    * stop demux
    */
-  if (stream->demux_plugin && stream->demux_thread) {
+  if (stream->demux_plugin && stream->demux_thread_created) {
     lprintf ("stopping demux\n");
     _x_demux_stop_thread( stream );
     lprintf ("demux stopped\n");
@@ -338,24 +332,28 @@ static void close_internal (xine_stream_t *stream) {
     }
   }
 
-  stream->ignore_speed_change = 1;
-  stream->xine->port_ticket->acquire(stream->xine->port_ticket, 1);
-
-  if (stream->audio_out)
-    stream->audio_out->set_property(stream->audio_out, AO_PROP_DISCARD_BUFFERS, 1);
-  if (stream->video_out)
-    stream->video_out->set_property(stream->video_out, VO_PROP_DISCARD_FRAMES, 1);
-
+  if( !stream->gapless_switch ) {
+    stream->ignore_speed_change = 1;
+    stream->xine->port_ticket->acquire(stream->xine->port_ticket, 1);
+  
+    if (stream->audio_out)
+      stream->audio_out->set_property(stream->audio_out, AO_PROP_DISCARD_BUFFERS, 1);
+    if (stream->video_out)
+      stream->video_out->set_property(stream->video_out, VO_PROP_DISCARD_FRAMES, 1);
+  }
+  
   stop_internal( stream );
   
-  if (stream->video_out)
-    stream->video_out->set_property(stream->video_out, VO_PROP_DISCARD_FRAMES, 0);  
-  if (stream->audio_out)
-    stream->audio_out->set_property(stream->audio_out, AO_PROP_DISCARD_BUFFERS, 0);
-
-  stream->xine->port_ticket->release(stream->xine->port_ticket, 1);
-  stream->ignore_speed_change = 0;
+  if( !stream->gapless_switch ) {
+    if (stream->video_out)
+      stream->video_out->set_property(stream->video_out, VO_PROP_DISCARD_FRAMES, 0);  
+    if (stream->audio_out)
+      stream->audio_out->set_property(stream->audio_out, AO_PROP_DISCARD_BUFFERS, 0);
   
+    stream->xine->port_ticket->release(stream->xine->port_ticket, 1);
+    stream->ignore_speed_change = 0;
+  }
+    
   if (stream->demux_plugin) {
     _x_free_demux_plugin(stream, stream->demux_plugin);
     stream->demux_plugin = NULL;
@@ -492,6 +490,8 @@ xine_stream_t *xine_stream_new (xine_t *this,
   stream->spu_channel_pan_scan   = -1;
   stream->spu_channel_user       = -1;
   stream->spu_channel            = -1;
+  stream->early_finish_event     = 0;
+  stream->gapless_switch         = 0;
 
   stream->video_out              = vo;
   if (vo)
@@ -1130,7 +1130,7 @@ static int play_internal (xine_stream_t *stream, int start_pos, int start_time)
   stream->xine->port_ticket->acquire(stream->xine->port_ticket, 1);
   
   /* only flush/discard output ports on master streams */
-  if( stream->master == stream ) {
+  if( stream->master == stream && !stream->gapless_switch) {
     /* discard audio/video buffers to get engine going and take the lock faster */
     if (stream->audio_out)
       stream->audio_out->set_property(stream->audio_out, AO_PROP_DISCARD_BUFFERS, 1);
@@ -1159,7 +1159,7 @@ static int play_internal (xine_stream_t *stream, int start_pos, int start_time)
 					     stream->demux_thread_running);
 
   /* only flush/discard output ports on master streams */
-  if( stream->master == stream ) {
+  if( stream->master == stream && !stream->gapless_switch) {
     if (stream->audio_out)
       stream->audio_out->set_property(stream->audio_out, AO_PROP_DISCARD_BUFFERS, 0);
     if (stream->video_out)
@@ -1217,6 +1217,8 @@ int xine_play (xine_stream_t *stream, int start_pos, int start_time) {
   ret = play_internal (stream, start_pos, start_time);
   if( stream->slave && (stream->slave_affection & XINE_MASTER_SLAVE_PLAY) )
     xine_play (stream->slave, start_pos, start_time);
+  
+  stream->gapless_switch = 0;
 
   pthread_mutex_unlock (&stream->frontend_lock);
   
@@ -1341,7 +1343,7 @@ void xine_exit (xine_t *this) {
 #if defined(WIN32)
   WSACleanup();
 #endif
-  
+
   free (this);
 }
 
@@ -1352,7 +1354,7 @@ xine_t *xine_new (void) {
 #ifdef WIN32
     WSADATA Data;
     int i_err;
-#endif /*  WIN32 */
+#endif
 
   this = xine_xmalloc (sizeof (xine_t));
   if (!this)
