@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2002 the xine project
+ * Copyright (C) 2000-2003 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: monitor.c,v 1.3 2002/03/21 21:30:51 guenter Exp $
+ * $Id: monitor.c,v 1.7 2003/12/09 00:02:39 f1rmb Exp $
  *
  * debug print and profiling functions - implementation
  *
@@ -64,7 +64,7 @@ int xine_profiler_allocate_slot (char *label) {
 }
 
 
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
 __inline__ unsigned long long int rdtsc()
 {
   unsigned long long int x;
@@ -77,7 +77,7 @@ void xine_profiler_start_count (int id) {
 
   if ((unsigned)id >= MAX_ID) return;
 
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
   profiler_start[id] = rdtsc();
 #endif
 }
@@ -86,7 +86,7 @@ void xine_profiler_stop_count (int id) {
 
   if ((unsigned)id >= MAX_ID) return;
 
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
   profiler_times[id] += rdtsc() - profiler_start[id];
 #endif
   profiler_calls[id]++;
@@ -95,7 +95,7 @@ void xine_profiler_stop_count (int id) {
 void xine_profiler_print_results () {
   int i;
 
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
   static long long int cpu_speed;	/* cpu cyles/usec */
   if (!cpu_speed) {
     long long int tsc_start, tsc_end;
@@ -125,7 +125,7 @@ void xine_profiler_print_results () {
 	      i, profiler_label[i], profiler_times[i], profiler_calls[i]);
       if (profiler_calls[i]) {
 	  printf(" %12lld", profiler_times[i] / profiler_calls[i]);
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
 	  printf(" %9lld", profiler_times[i] / (cpu_speed * profiler_calls[i]));
 #endif
       }
@@ -134,4 +134,26 @@ void xine_profiler_print_results () {
   }
 }
 
+
+#else /* DEBUG */
+
+#define NO_PROFILER_MSG  {printf("xine's profiler is unavailable.\n");}
+
+/* Dummies */
+void xine_profiler_init (void) {
+  NO_PROFILER_MSG
+}
+int xine_profiler_allocate_slot (char *label) {
+  return -1;
+}
+void xine_profiler_start_count (int id) {
+}
+void xine_profiler_stop_count (int id) {
+}
+void xine_profiler_print_results (void) {
+  NO_PROFILER_MSG
+}
+
 #endif
+
+
